@@ -10,6 +10,12 @@
 #include <math.h>
 
 
+//replaced TEST_ASSERT_EQUAL_MEMORY(&a,&b,sizeof(a)) with TEST_ASSERT_EQUAL_l_fp(a,b). It's safer this way, because structs can be compared even if they aren't initiated with memset (due to padding bytes)
+#define TEST_ASSERT_EQUAL_l_fp(a, b) { \
+    TEST_ASSERT_EQUAL_MESSAGE(a.l_i, b.l_i, "Field l_i"); \
+    TEST_ASSERT_EQUAL_UINT_MESSAGE(a.l_uf, b.l_uf, "Field l_uf");	\
+}
+
 typedef struct  {
 	uint32_t h, l;
 } lfp_hl;
@@ -312,7 +318,7 @@ double eps(double d)
 //----------------------------------------------------------------------
 // test addition
 //----------------------------------------------------------------------
-void test_AdditionLR() {
+void test_AdditionLR(void) {
 	
 	size_t idx=0;
 	for (idx=0; idx < addsub_cnt; ++idx) {
@@ -326,11 +332,12 @@ void test_AdditionLR() {
 		//LFP res(op1 + op2);
 		l_fp res = l_fp_add(op1,op2);		
 
-		TEST_ASSERT_EQUAL_MEMORY(&exp, &res,sizeof(exp));
+		TEST_ASSERT_EQUAL_l_fp(exp,res);
+		//TEST_ASSERT_EQUAL_MEMORY(&exp, &res,sizeof(exp));
 	}	
 }
 
-void test_AdditionRL() {
+void test_AdditionRL(void) {
 
 	size_t idx=0;
 	for (idx=0; idx < addsub_cnt; ++idx) {
@@ -339,7 +346,8 @@ void test_AdditionRL() {
 		l_fp exp = l_fp_init(addsub_tab[idx][2].h, addsub_tab[idx][2].l);
 		l_fp res = l_fp_add(op1,op2);
 
-		TEST_ASSERT_EQUAL_MEMORY(&exp, &res,sizeof(exp));
+		TEST_ASSERT_EQUAL_l_fp(exp,res);
+		//TEST_ASSERT_EQUAL_MEMORY(&exp, &res,sizeof(exp));
 	}	
 }
 
@@ -348,7 +356,7 @@ void test_AdditionRL() {
 //----------------------------------------------------------------------
 // test subtraction
 //----------------------------------------------------------------------
-void test_SubtractionLR() {
+void test_SubtractionLR(void) {
 
 	size_t idx=0;
 	for (idx=0; idx < addsub_cnt; ++idx) {
@@ -357,12 +365,13 @@ void test_SubtractionLR() {
 		l_fp op1 = l_fp_init(addsub_tab[idx][2].h, addsub_tab[idx][2].l);
 		l_fp res = l_fp_subtract(op1,op2);
 		//LFP res(op1 - op2);
-				
-		TEST_ASSERT_EQUAL_MEMORY(&exp, &res,sizeof(exp));
+		
+		TEST_ASSERT_EQUAL_l_fp(exp,res);		
+		//TEST_ASSERT_EQUAL_MEMORY(&exp, &res,sizeof(exp));
 	}	
 }
 
-void test_SubtractionRL() {
+void test_SubtractionRL(void) {
 
 	size_t idx=0;
 	for (idx=0; idx < addsub_cnt; ++idx) {
@@ -371,7 +380,8 @@ void test_SubtractionRL() {
 		l_fp op1 = l_fp_init(addsub_tab[idx][2].h, addsub_tab[idx][2].l);
 		l_fp res = l_fp_subtract(op1,op2);
 
-		TEST_ASSERT_EQUAL_MEMORY(&exp, &res,sizeof(exp));
+		TEST_ASSERT_EQUAL_l_fp(exp,res);
+		//TEST_ASSERT_EQUAL_MEMORY(&exp, &res,sizeof(exp));
 	}	
 }
 
@@ -379,7 +389,7 @@ void test_SubtractionRL() {
 // test negation
 //----------------------------------------------------------------------
 
-void test_Negation() {
+void test_Negation(void) {
 
 	size_t idx=0;
 	for (idx=0; idx < addsub_cnt; ++idx) {
@@ -388,7 +398,9 @@ void test_Negation() {
 		l_fp sum = l_fp_add(op1, op2);
 		
 		l_fp zero = l_fp_init(0,0);
-		TEST_ASSERT_EQUAL_MEMORY(&zero, &sum,sizeof(sum));
+
+		TEST_ASSERT_EQUAL_l_fp(zero,sum);
+		//TEST_ASSERT_EQUAL_MEMORY(&zero, &sum,sizeof(sum));
 	
 	}	
 }
@@ -398,7 +410,7 @@ void test_Negation() {
 //----------------------------------------------------------------------
 // test absolute value
 //----------------------------------------------------------------------
-void test_Absolute() {
+void test_Absolute(void) {
 	size_t idx=0;
 	for (idx=0; idx < addsub_cnt; ++idx) {
 		l_fp op1 = l_fp_init(addsub_tab[idx][0].h, addsub_tab[idx][0].l);
@@ -413,7 +425,9 @@ void test_Absolute() {
 			op1 = l_fp_add(op1,op2);
 		
 		l_fp zero = l_fp_init(0,0);
-		TEST_ASSERT_EQUAL_MEMORY(&zero, &op1,sizeof(op1));
+		
+		TEST_ASSERT_EQUAL_l_fp(zero,op1);
+		//TEST_ASSERT_EQUAL_MEMORY(&zero, &op1,sizeof(op1));
 	}
 
 	// There is one special case we have to check: the minimum
@@ -422,14 +436,16 @@ void test_Absolute() {
 	l_fp minVal = l_fp_init(0x80000000, 0x00000000);
 	l_fp minAbs = l_fp_abs(minVal);
 	TEST_ASSERT_EQUAL(-1, l_fp_signum(minVal));
-	TEST_ASSERT_EQUAL_MEMORY(&minVal, &minAbs,sizeof(minAbs));
+
+	TEST_ASSERT_EQUAL_l_fp(minVal,minAbs);
+	//TEST_ASSERT_EQUAL_MEMORY(&minVal, &minAbs,sizeof(minAbs));
 }
 
 
 //----------------------------------------------------------------------
 // fp -> double -> fp rountrip test
 //----------------------------------------------------------------------
-void test_FDF_RoundTrip() {
+void test_FDF_RoundTrip(void) {
 	// since a l_fp has 64 bits in it's mantissa and a double has
 	// only 54 bits available (including the hidden '1') we have to
 	// make a few concessions on the roundtrip precision. The 'eps()'
@@ -450,6 +466,7 @@ void test_FDF_RoundTrip() {
  		TEST_ASSERT_DOUBLE_WITHIN(eps(op2),0.0, fabs(d)); //delta,epected,actual
 		  		
 		//ASSERT_LE(fabs(op1-op3), eps(op2)); //unity has no equivalent of LE!!!
+		//you could use TEST_ASSERT_TRUE(IsLE(fabs(op1-op3), eps(op2)));
 	}	
 }
 
@@ -460,8 +477,7 @@ void test_FDF_RoundTrip() {
 // This uses the local compare and checks if the operations using the
 // macros in 'ntp_fp.h' produce mathing results.
 // ----------------------------------------------------------------------
-void test_SignedRelOps() {
-	//const lfp_hl * tv(&addsub_tab[0][0]);
+void test_SignedRelOps(void) {
 	const lfp_hl * tv = (&addsub_tab[0][0]);
 	size_t lc ;
 	for (lc=addsub_tot-1; lc; --lc,++tv) {
@@ -503,7 +519,7 @@ void test_SignedRelOps() {
 	}
 }
 
-void test_UnsignedRelOps() {
+void test_UnsignedRelOps(void) {
 	const lfp_hl * tv =(&addsub_tab[0][0]);	
 	size_t lc;
 	for (lc=addsub_tot-1; lc; --lc,++tv) {
