@@ -63,11 +63,9 @@ bool AssertTimevalClose(const struct timeval m, const struct timeval n, const st
 	
 	else 
 	{
-		//printf("");
-		//<< m_expr << " which is " << timeval_wrap(m)
-		//<< "\nand\n"
-		//<< n_expr << " which is " << timeval_wrap(n)
-		//<< "\nare not close; diff=" << timeval_wrap(diff);
+		printf("m_expr which is %ld.%lu \nand\nn_expr which is %ld.%lu\nare not close; diff=%ld.%luusec\n",m.tv_sec,m.tv_usec,n.tv_sec,n.tv_usec,diff.tv_sec,diff.tv_usec); 
+		//I don't have variables m_expr and n_expr in unity, those are command line arguments which only getst has!!!
+		
 		return FALSE;
 	}
 }
@@ -87,10 +85,8 @@ bool AssertFpClose(const l_fp m,const l_fp n, const l_fp limit)
 		return TRUE;
 	}
 	else {
-		//<< m_expr << " which is " << l_fp_wrap(m)
-		//<< "\nand\n"
-		//<< n_expr << " which is " << l_fp_wrap(n)
-		//<< "\nare not close; diff=" << l_fp_wrap(diff);
+		printf("m_expr which is %s \nand\nn_expr which is %s\nare not close; diff=%susec\n",lfptoa(&m,10),lfptoa(&n,10),lfptoa(&diff,10)); 
+		//printf("m_expr which is %d.%d \nand\nn_expr which is %d.%d\nare not close; diff=%d.%dusec\n",m.l_uf,m.Ul_i,n.l_uf,n.Ul_i,diff.l_uf,diff.Ul_i); 
 		return FALSE;
 	}
 }
@@ -150,7 +146,7 @@ u_int32 my_tsf_to_tick(u_int32 tsf)
 // test support stuff - part1
 // ---------------------------------------------------------------------
 
-void test_Helpers1() {
+void test_Helpers1(void) {
 	struct timeval x;
 
 	for (x.tv_sec = -2; x.tv_sec < 3; x.tv_sec++) {
@@ -170,7 +166,7 @@ void test_Helpers1() {
 // test normalisation
 //----------------------------------------------------------------------
 
-void test_Normalise() {
+void test_Normalise(void) {
 	long ns;
 	for (ns = -2000000000; ns <= 2000000000; ns += 10000000) {
 		struct timeval x = timeval_init(0, ns);
@@ -184,7 +180,7 @@ void test_Normalise() {
 // test classification
 //----------------------------------------------------------------------
 
-void test_SignNoFrac() {
+void test_SignNoFrac(void) {
 	int i;
 	// sign test, no fraction
 	for (i = -4; i <= 4; ++i) {
@@ -196,7 +192,7 @@ void test_SignNoFrac() {
 	}
 }
 
-void test_SignWithFrac() {
+void test_SignWithFrac(void) {
 	// sign test, with fraction
 	int i;
 	for (i = -4; i <= 4; ++i) {
@@ -211,7 +207,7 @@ void test_SignWithFrac() {
 //----------------------------------------------------------------------
 // test compare
 //----------------------------------------------------------------------
-void test_CmpFracEQ() {
+void test_CmpFracEQ(void) {
 	int i,j;
 	// fractions are equal
 	for (i = -4; i <= 4; ++i)
@@ -225,7 +221,7 @@ void test_CmpFracEQ() {
 		}
 }
 
-void test_CmpFracGT() {
+void test_CmpFracGT(void) {
 	// fraction a bigger fraction b
 	int i,j;
 	for (i = -4; i <= 4; ++i)
@@ -239,7 +235,7 @@ void test_CmpFracGT() {
 		}
 }
 
-void test_CmpFracLT() {
+void test_CmpFracLT(void) {
 	// fraction a less fraction b
 	int i,j;
 	for (i = -4; i <= 4; ++i)
@@ -257,7 +253,7 @@ void test_CmpFracLT() {
 // Test addition (sum)
 //----------------------------------------------------------------------
 
-void test_AddFullNorm() {
+void test_AddFullNorm(void) {
 	int i,j;
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
@@ -271,7 +267,7 @@ void test_AddFullNorm() {
 		}
 }
 
-void test_AddFullOflow1() {
+void test_AddFullOflow1(void) {
 	int i,j;
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
@@ -285,7 +281,7 @@ void test_AddFullOflow1() {
 		}
 }
 
-void test_AddUsecNorm() {
+void test_AddUsecNorm(void) {
 	int i;
 	for (i = -4; i <= 4; ++i) {
 		struct timeval a = timeval_init(i, 200);
@@ -297,7 +293,7 @@ void test_AddUsecNorm() {
 	}
 }
 
-void test_AddUsecOflow1() {
+void test_AddUsecOflow1(void) {
 	int i;
 	for (i = -4; i <= 4; ++i) {
 		struct timeval a = timeval_init(i, 200);
@@ -313,7 +309,7 @@ void test_AddUsecOflow1() {
 // test subtraction (difference)
 //----------------------------------------------------------------------
 
-void test_SubFullNorm() {
+void test_SubFullNorm(void) {
 	int i,j;
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
@@ -327,7 +323,7 @@ void test_SubFullNorm() {
 		}
 }
 
-void test_SubFullOflow() {
+void test_SubFullOflow(void) {
 	int i,j;
 	for (i = -4; i <= 4; ++i)
 		for (j = -4; j <= 4; ++j) {
@@ -341,7 +337,7 @@ void test_SubFullOflow() {
 		}
 }
 
-void test_SubUsecNorm() {
+void test_SubUsecNorm(void) {
 	int i = -4;
 	for (i = -4; i <= 4; ++i) {
 		struct timeval a = timeval_init(i, 600);
@@ -353,7 +349,7 @@ void test_SubUsecNorm() {
 	}
 }
 
-void test_SubUsecOflow() {
+void test_SubUsecOflow(void) {
 	int i = -4;
 	for (i = -4; i <= 4; ++i) {
 		struct timeval a = timeval_init(i, 100);
@@ -369,7 +365,7 @@ void test_SubUsecOflow() {
 // test negation
 //----------------------------------------------------------------------
 
-void test_Neg() {
+void test_Neg(void) {
 	int i = -4;
 	for (i = -4; i <= 4; ++i) {
 		struct timeval a = timeval_init(i, 100);
@@ -386,7 +382,7 @@ void test_Neg() {
 // test abs value
 //----------------------------------------------------------------------
 
-void test_AbsNoFrac() {
+void test_AbsNoFrac(void) {
 	int i = -4;
 	for (i = -4; i <= 4; ++i) {
 		struct timeval a = timeval_init(i, 0);
@@ -397,7 +393,7 @@ void test_AbsNoFrac() {
 	}
 }
 
-void test_AbsWithFrac() {
+void test_AbsWithFrac(void) {
 	int i = -4;
 	for (i = -4; i <= 4; ++i) {
 		struct timeval a = timeval_init(i, 100);
@@ -413,8 +409,8 @@ void test_AbsWithFrac() {
 // ---------------------------------------------------------------------
 
 
-void test_Helpers2() {
-	//struct AssertTimevalClose isClose = AssertTimevalClose_init(0, 2);
+void test_Helpers2(void) {
+
 	struct timeval limit = timeval_init(0, 2);
 	struct timeval x, y;
 	long i;	
@@ -430,7 +426,7 @@ void test_Helpers2() {
 					TEST_ASSERT_TRUE(AssertTimevalClose(x,y,limit));//ASSERT_PRED_FORMAT2(isClose, x, y);
 				}
 				else {
-					TEST_ASSERT_FALSE(AssertTimevalClose(x,y,limit));//ASSERT_PRED_FORMAT2(!isClose, x, y);
+					TEST_ASSERT_FALSE(AssertTimevalClose(x,y,limit));
 				}
 			}
 		}
@@ -446,7 +442,7 @@ void test_Helpers2() {
 // conversion to l_fp
 //----------------------------------------------------------------------
 
-void test_ToLFPbittest() {
+void test_ToLFPbittest(void) {
 	l_fp lfpClose =  l_fp_init(0,1);	
 
 	u_int32 i = 0;
@@ -461,7 +457,7 @@ void test_ToLFPbittest() {
 }
 
 
-void test_ToLFPrelPos() {
+void test_ToLFPrelPos(void) {
 	l_fp lfpClose =  l_fp_init(0,1);
 
 	int i = 0;
@@ -471,11 +467,11 @@ void test_ToLFPrelPos() {
 		l_fp r;
 
 		r = tval_intv_to_lfp(a);
-		TEST_ASSERT_TRUE(AssertFpClose(E,r,lfpClose)); //ASSERT_PRED_FORMAT2(FpClose, E, r);
+		TEST_ASSERT_TRUE(AssertFpClose(E,r,lfpClose));
 	}
 }
 
-void test_ToLFPrelNeg() {
+void test_ToLFPrelNeg(void) {
 	l_fp lfpClose =  l_fp_init(0,1);
 	int i = 0;
 	for (i = 0; i < COUNTOF(fdata); i++) {
@@ -484,11 +480,11 @@ void test_ToLFPrelNeg() {
 		l_fp    r;
 
 		r = tval_intv_to_lfp(a);
-		TEST_ASSERT_TRUE(AssertFpClose(E,r,lfpClose)); //ASSERT_PRED_FORMAT2(FpClose,E, r);
+		TEST_ASSERT_TRUE(AssertFpClose(E,r,lfpClose));
 	}
 }
 
-void test_ToLFPabs() {
+void test_ToLFPabs(void) {
 	l_fp lfpClose =  l_fp_init(0,1);
 
 	int i = 0;
@@ -498,7 +494,7 @@ void test_ToLFPabs() {
 		l_fp    r;
 
 		r = tval_stamp_to_lfp(a);
-		TEST_ASSERT_TRUE(AssertFpClose(E,r,lfpClose)); //ASSERT_PRED_FORMAT2(FpClose, E, r);
+		TEST_ASSERT_TRUE(AssertFpClose(E,r,lfpClose));
 	}
 }
 
@@ -506,7 +502,7 @@ void test_ToLFPabs() {
 // conversion from l_fp
 //----------------------------------------------------------------------
 
-void test_FromLFPbittest() {
+void test_FromLFPbittest(void) {
 	struct timeval timevalClose = timeval_init(0,1);
 	// Not *exactly* a bittest, because 2**32 tests would take a
 	// really long time even on very fast machines! So we do test
@@ -520,11 +516,11 @@ void test_FromLFPbittest() {
 		r = lfp_intv_to_tval(a);
 		// The conversion might be off by one microsecond when
 		// comparing to calculated value.
-		TEST_ASSERT_TRUE(AssertTimevalClose(E,r,timevalClose)); //ASSERT_PRED_FORMAT2(TimevalClose, E, r);
+		TEST_ASSERT_TRUE(AssertTimevalClose(E,r,timevalClose));
 	}
 }
 
-void test_FromLFPrelPos() {
+void test_FromLFPrelPos(void) {
 	struct timeval timevalClose = timeval_init(0,1);
 	int i = 0;	
 	for (i = 0; i < COUNTOF(fdata); i++) {
@@ -533,11 +529,11 @@ void test_FromLFPrelPos() {
 		struct timeval r;
 
 		r = lfp_intv_to_tval(a);
-		TEST_ASSERT_TRUE(AssertTimevalClose(E,r,timevalClose)); //ASSERT_PRED_FORMAT2(TimevalClose, E, r);
+		TEST_ASSERT_TRUE(AssertTimevalClose(E,r,timevalClose));
 	}
 }
 
-void test_FromLFPrelNeg() {
+void test_FromLFPrelNeg(void) {
 	struct timeval timevalClose = timeval_init(0,1);
 	int i = 0;
 	for (i = 0; i < COUNTOF(fdata); i++) {
@@ -546,12 +542,12 @@ void test_FromLFPrelNeg() {
 		struct timeval r;
 
 		r = lfp_intv_to_tval(a);
-		TEST_ASSERT_TRUE(AssertTimevalClose(E,r,timevalClose)); //ASSERT_PRED_FORMAT2(TimevalClose, E, r);
+		TEST_ASSERT_TRUE(AssertTimevalClose(E,r,timevalClose));
 	}
 }
 
 // usec -> frac -> usec roundtrip, using a prime start and increment
-void test_LFProundtrip() {
+void test_LFProundtrip(void) {
 	int32_t t = -1;
 	u_int32 i = 5;
 	for (t = -1; t < 2; ++t)
@@ -570,7 +566,7 @@ void test_LFProundtrip() {
 // string formatting
 //----------------------------------------------------------------------
 
-void test_ToString() {
+void test_ToString(void) {
 	static const struct {
 		time_t	     sec;
 		long	     usec;
@@ -588,7 +584,7 @@ void test_ToString() {
 	int i;
 	for (i = 0; i < COUNTOF(data); ++i) {
 		struct timeval a = timeval_init(data[i].sec, data[i].usec);
-		const char *  E = data[i].repr; //??
+		const char *  E = data[i].repr;
 		const char *  r = tvaltoa(a);
 
 		TEST_ASSERT_EQUAL_STRING(E, r);
